Em TJSP1:
1. Opção para utilizar outros itens no buscados.

Em outros estados:
2. Add opção de TRFs

Outros:
1. Add opção para que função salve resultado em excel ou csv diretamente.
2. Acrescentar opção para iterar por vários anos.
3. Acrescentar opção para permitir baixar por bimestre, trimestre ou quadrimestre.